@@ -9,7 +9,7 @@
 
 from __future__ import with_statement
 
-__version__ = '0.5.19'
+__version__ = '0.5.24'
 
 # import sip
 # sip.setapi('QString', 2)
@@ -33,69 +33,17 @@ except:
 
 from qbadgebutton import QToolBadgeButton
 
-
-
 import os
 import sys
 from list_view import KhweetsView
 from list_model import KhweetsModel, ISMEROLE, IDROLE, ORIGINROLE, SCREENNAMEROLE, PROTECTEDROLE, USERIDROLE
 
-import dbus.service
 
 try:
     from QtMobility.Location import QGeoPositionInfoSource
 except:
     print 'Pyside QtMobility not installed or broken'
 
-class KhweeteurDBusHandler(dbus.service.Object):
-
-    def __init__(self, parent):
-        dbus.service.Object.__init__(self, dbus.SessionBus(),
-                                     '/net/khertan/Khweeteur')
-        self.parent = parent
-
-        # Post Folder
-
-        self.post_path = os.path.join(os.path.expanduser('~'), '.khweeteur',
-                                      'topost')
-
-    @dbus.service.signal(dbus_interface='net.khertan.Khweeteur')
-    def require_update(self, optional=None):
-        try:
-            self.parent.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, True)
-        except:
-            pass
-
-    def post_tweet(
-        self,
-        shorten_url=1,
-        serialize=1,
-        text='',
-        lattitude='0',
-        longitude='0',
-        base_url='',
-        action='',
-        tweet_id='0',
-        ):
-        import time
-        import pickle
-        if not os.path.exists(self.post_path):
-            os.makedirs(self.post_path)
-        with open(os.path.join(self.post_path, str(time.time())), 'wb') as \
-            fhandle:
-            post = {
-                'shorten_url': shorten_url,
-                'serialize': serialize,
-                'text': text,
-                'lattitude': lattitude,
-                'longitude': longitude,
-                'base_url': base_url,
-                'action': action,
-                'tweet_id': tweet_id,
-                }
-            pickle.dump(post, fhandle, pickle.HIGHEST_PROTOCOL)
-
-
 class KhweeteurAbout(QMainWindow):
 
     '''About Window'''
@@ -107,12 +55,7 @@ class KhweeteurAbout(QMainWindow):
         self.settings = QSettings()
 
         try:  # Preferences not set yet
-            if int(self.settings.value('useAutoRotation')) == 2:
-                self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-        except:
             self.setAttribute(Qt.WA_Maemo5AutoOrientation, True)
-
-        try:
             self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
         except:
             pass
@@ -238,7 +181,7 @@ class Khweeteur(QApplication):
             import urllib
             import pickle
             if (( QMessageBox.question(None,
-                "Kheeteur Crash Report",
+                "Khweeteur Crash Report",
                 "An error occur on Khweeteur in the previous launch. Report this bug on the bug tracker ?",
                 QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
                 url = 'http://khertan.net/report.php' # write ur URL here
@@ -275,7 +218,7 @@ class Khweeteur(QApplication):
                 else:
                     print 'page:',the_page
                     QMessageBox.question(None,
-                    "KhtEditor Crash Report",
+                    "Khweeteur Crash Report",
                     "%s" % the_page,
                     QMessageBox.Close)
                     return False
@@ -287,8 +230,6 @@ class Khweeteur(QApplication):
     def run(self):
         self.check_crash_report()
         self.win = KhweeteurWin()
-        self.win.show()
-
 
 class KhweeteurWin(QMainWindow):
 
@@ -302,6 +243,7 @@ class KhweeteurWin(QMainWindow):
             self.setAttribute(Qt.WA_Maemo5StackedWindow, True)
         except:
             pass
+
         self.setWindowTitle('Khweeteur')
 
         settings = QSettings()
@@ -318,6 +260,7 @@ class KhweeteurWin(QMainWindow):
         self.view.clicked.connect(self.switch_tb_action)
 
         self.toolbar = QToolBar('Toolbar')
+#        self.toolbar.setMovable(False)
         self.addToolBar(Qt.BottomToolBarArea, self.toolbar)
 
         self.toolbar_mode = 0  # 0 - Default , 1 - Edit, 2 - Action
@@ -395,6 +338,14 @@ class KhweeteurWin(QMainWindow):
         self.tb_list_button.clicked.connect(self.show_list)
         self.list_tb_action.append(self.toolbar.addWidget(self.tb_list_button))
 
+        # Near (Default)
+        self.near_button = QToolBadgeButton(self)
+        self.near_button.setText('Nears')
+        self.near_button.setIcon(QIcon.fromTheme('general_web'))
+        self.near_button.setCheckable(True)
+        self.near_button.clicked.connect(self.show_nears)
+        self.list_tb_action.append(self.toolbar.addWidget(self.near_button))
+
         # Fullscreen
 
         self.tb_fullscreen = QAction(QIcon.fromTheme('general_fullsize'),
@@ -403,42 +354,29 @@ class KhweeteurWin(QMainWindow):
         self.toolbar.addAction(self.tb_fullscreen)
         self.list_tb_action.append(self.tb_fullscreen)
 
-        # Actions not in toolbar
-
-        self.tb_scrolltop = QAction('Scroll to top', self)
-        self.tb_scrolltop.setShortcut(Qt.CTRL + Qt.Key_Up)
-        self.tb_scrolltop.triggered.connect(self.view.scrollToTop)
-        self.addAction(self.tb_scrolltop)
-
-        self.tb_scrollbottom = QAction('Scroll to bottom', self)
-        self.tb_scrollbottom.setShortcut(Qt.CTRL + Qt.Key_Down)
-        self.tb_scrollbottom.triggered.connect(self.view.scrollToBottom)
-        self.addAction(self.tb_scrollbottom)
-
-        self.tb_zoomin = QAction('ZoomIn', self)
-        self.tb_zoomin.setShortcut(Qt.CTRL + Qt.Key_Left)
-        self.tb_zoomin.triggered.connect(self.view.do_zoom_in)
-        self.addAction(self.tb_zoomin)
-
-        self.tb_zoomout = QAction('ZoomOut', self)
-        self.tb_zoomout.setShortcut(Qt.CTRL + Qt.Key_Right)
-        self.tb_zoomout.triggered.connect(self.view.do_zoom_out)
-        self.addAction(self.tb_zoomout)
-
-        self.tb_copy = QAction('Copy', self)
-        self.tb_copy.setShortcut(Qt.CTRL + Qt.Key_C)
-        self.tb_copy.triggered.connect(self.do_tb_copy)
-        self.addAction(self.tb_copy)
-
-#        self.switch_tb_default()
-
         self.setWindowTitle('Khweeteur : Home')
-        self.model.load('HomeTimeline')
+
         self.show()
-        QTimer.singleShot(500,self.post_init)
+
+        self.model.load('HomeTimeline',limit=5)
+        QTimer.singleShot(0,self.post_init_2)
+        QTimer.singleShot(0,self.post_init_3)
+        QApplication.processEvents()
 
     @Slot()
-    def post_init(self):
+    def post_init_3(self):
+        self.model.load('HomeTimeline')
+        #Check if there is at least one account
+        nb_accounts = QSettings().beginReadArray('accounts')
+        if not nb_accounts:
+            if (( QMessageBox.question(None,
+                "Khweeteur",
+                'None microblogging account found, would you want to add one now in preferences ?',
+                QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
+                    self.showPrefs()
+
+    @Slot()
+    def post_init_2(self):
         self.listen_dbus()
         self.dbus_handler.require_update()
         self.tb_update.triggered.connect(self.dbus_handler.require_update)
@@ -504,7 +442,6 @@ class KhweeteurWin(QMainWindow):
         self.action_tb_action.append(self.tb_reply)
 
         # Retweet (Action)
-
         self.tb_retweet = QAction('Retweet', self)
         self.tb_retweet.setShortcut('Ctrl+P')
         self.tb_retweet.setVisible(False)
@@ -512,8 +449,14 @@ class KhweeteurWin(QMainWindow):
         self.tb_retweet.triggered.connect(self.do_tb_retweet)
         self.action_tb_action.append(self.tb_retweet)
 
-        # Follow (Action)
+        # RT (Action)
+        self.tb_rt = QAction('RT', self)
+        self.tb_rt.setVisible(False)
+        self.toolbar.addAction(self.tb_rt)
+        self.tb_rt.triggered.connect(self.do_tb_rt)
+        self.action_tb_action.append(self.tb_rt)
 
+        # Follow (Action)
         self.tb_follow = QAction('Follow', self)
         self.tb_follow.triggered.connect(self.do_tb_follow)
         self.tb_follow.setVisible(False)
@@ -521,7 +464,6 @@ class KhweeteurWin(QMainWindow):
         self.action_tb_action.append(self.tb_follow)
 
         # UnFollow (Action)
-
         self.tb_unfollow = QAction('Unfollow', self)
         self.tb_unfollow.triggered.connect(self.do_tb_unfollow)
         self.tb_unfollow.setVisible(False)
@@ -538,7 +480,7 @@ class KhweeteurWin(QMainWindow):
 
         # Open URLs (Action)
 
-        self.tb_urls = QAction('Open URLs', self)
+        self.tb_urls = QAction('URLs', self)
         self.tb_urls.setShortcut('Ctrl+O')
         self.tb_urls.setVisible(False)
         self.toolbar.addAction(self.tb_urls)
@@ -553,6 +495,33 @@ class KhweeteurWin(QMainWindow):
         self.tb_delete.triggered.connect(self.do_tb_delete)
         self.action_tb_action.append(self.tb_delete)
 
+        # Actions not in toolbar
+
+        self.tb_scrolltop = QAction('Scroll to top', self)
+        self.tb_scrolltop.setShortcut(Qt.CTRL + Qt.Key_Up)
+        self.tb_scrolltop.triggered.connect(self.view.scrollToTop)
+        self.addAction(self.tb_scrolltop)
+
+        self.tb_scrollbottom = QAction('Scroll to bottom', self)
+        self.tb_scrollbottom.setShortcut(Qt.CTRL + Qt.Key_Down)
+        self.tb_scrollbottom.triggered.connect(self.view.scrollToBottom)
+        self.addAction(self.tb_scrollbottom)
+
+        self.tb_zoomin = QAction('ZoomIn', self)
+        self.tb_zoomin.setShortcut(Qt.CTRL + Qt.Key_Left)
+        self.tb_zoomin.triggered.connect(self.view.do_zoom_in)
+        self.addAction(self.tb_zoomin)
+
+        self.tb_zoomout = QAction('ZoomOut', self)
+        self.tb_zoomout.setShortcut(Qt.CTRL + Qt.Key_Right)
+        self.tb_zoomout.triggered.connect(self.view.do_zoom_out)
+        self.addAction(self.tb_zoomout)
+
+        self.tb_copy = QAction('Copy', self)
+        self.tb_copy.setShortcut(Qt.CTRL + Qt.Key_C)
+        self.tb_copy.triggered.connect(self.do_tb_copy)
+        self.addAction(self.tb_copy)
+
     @Slot()
     def do_tb_fullscreen(self):
         if self.isFullScreen():
@@ -580,10 +549,12 @@ class KhweeteurWin(QMainWindow):
     def listen_dbus(self):
         import dbus
         import dbus.service
-        from dbusobj import KhweeteurDBus
-        from dbus.mainloop.qt import DBusQtMainLoop
-        self.dbus_loop = DBusQtMainLoop()
-        dbus.set_default_main_loop(self.dbus_loop)
+        from dbushandler import KhweeteurDBusHandler
+        import dbus.mainloop.glib
+        #from dbus.mainloop.qt import DBusQtMainLoop
+        #self.dbus_loop = DBusQtMainLoop()
+        dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
+        #dbus.set_default_main_loop(self.dbus_loop)
         self.bus = dbus.SessionBus()
 
         # Connect the new tweet signal
@@ -597,12 +568,14 @@ class KhweeteurWin(QMainWindow):
                                      dbus_interface='net.khertan.Khweeteur',
                                      signal_name='refresh_ended')
         self.dbus_handler = KhweeteurDBusHandler(self)
+        self.dbus_handler.attach_win(self)
         self.activated_by_dbus.connect(self.activateWindow)
-        dbusobj = KhweeteurDBus()
-        dbusobj.attach_win(self)
 
     def stop_spinning(self):
-        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+        try:
+            self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator, False)
+        except AttributeError:
+            pass
 
     def new_tweets(self, count, msg):
         if msg == 'HomeTimeline':
@@ -615,6 +588,9 @@ class KhweeteurWin(QMainWindow):
         elif msg == 'DMs':
             self.msg_button.setCounter(self.msg_button.getCounter() + count)
             self.msg_button.update()
+        elif msg == 'Nears':
+            self.near_button.setCounter(self.near_button.getCounter() + count)
+            self.near_button.update()
         elif msg.startswith('Search:'):
             self.tb_search_button.setCounter(self.tb_search_button.getCounter()
                     + count)
@@ -636,6 +612,7 @@ class KhweeteurWin(QMainWindow):
         self.tb_search_button.setChecked(True)
         self.mention_button.setChecked(False)
         self.tb_list_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.view.scrollToTop()
         self.model.load('Search:' + terms)
         self.delete_search_action.setVisible(True)
@@ -653,6 +630,7 @@ class KhweeteurWin(QMainWindow):
         self.tb_search_button.setChecked(False)
         self.tb_list_button.setChecked(True)
         self.mention_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.view.scrollToTop()
         self.model.load('List:' + user + ':' + tid)
         self.delete_search_action.setVisible(True)
@@ -664,6 +642,7 @@ class KhweeteurWin(QMainWindow):
         self.home_button.setChecked(True)
         self.msg_button.setChecked(False)
         self.tb_search_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.tb_list_button.setChecked(False)
         self.mention_button.setChecked(False)
         self.view.scrollToTop()
@@ -778,8 +757,8 @@ class KhweeteurWin(QMainWindow):
             1,
             1,
             self.tb_text.toPlainText(),
-            ('' if self.geoloc_source == None else self.geoloc_source[0]),
-            ('' if self.geoloc_source == None else self.geoloc_source[1]),
+            ('' if self.geoloc_source == None else self.geoloc_coordinates[0]),
+            ('' if self.geoloc_source == None else self.geoloc_coordinates[1]),
             ('' if is_not_reply else self.tb_text_reply_base_url),
             ('tweet' if is_not_reply else 'reply'),
             ('' if is_not_reply else str(self.tb_text_reply_id)),
@@ -803,6 +782,23 @@ class KhweeteurWin(QMainWindow):
             self.tb_text_reply_base_url = tweet_source
             self.switch_tb_edit()
 
+    @Slot()
+    def do_tb_rt(self):
+        tweet_id = None
+        for index in self.view.selectedIndexes():
+            tweet_id = self.model.data(index, role=IDROLE)
+            tweet_screenname = self.model.data(index, role=SCREENNAMEROLE)
+            tweet_text = self.model.data(index, role=Qt.DisplayRole)
+        if tweet_id:
+            self.tb_text.setPlainText('RT @%s: %s' % (tweet_screenname, tweet_text))
+            cur = self.tb_text.textCursor()
+            cur.movePosition(QTextCursor.End, QTextCursor.MoveAnchor)
+            self.tb_text.setTextCursor(cur)
+            self.switch_tb_edit()
+            self.tb_text.show()
+            self.tb_text.updateGeometry()
+            self.tb_text.textChanged.emit()
+
     @Slot()
     def do_tb_retweet(self):
 
@@ -818,7 +814,7 @@ class KhweeteurWin(QMainWindow):
                                      % screenname, QMessageBox.Close)
 
         if not (( QMessageBox.question(None,
-            "Kheeteur Retweet",
+            "Khweeteur Retweet",
             "Did you want to retweet '%s'?" % tweet_text,
             QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
             tweet_id = None
@@ -852,7 +848,7 @@ class KhweeteurWin(QMainWindow):
             tweet_text = self.model.data(index, role=Qt.DisplayRole)
 
         if not (( QMessageBox.question(None,
-            "Kheeteur Delete",
+            "Khweeteur Delete",
             "Did you really want to delete '%s'?" % tweet_text,
             QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
             tweet_id = None
@@ -886,7 +882,7 @@ class KhweeteurWin(QMainWindow):
             tweet_text = self.model.data(index, role=Qt.DisplayRole)
 
         if not (( QMessageBox.question(None,
-            "Kheeteur Favorite",
+            "Khweeteur Favorite",
             "Did you really want to favorite '%s'?" % tweet_text,
             QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
             tweet_id = None
@@ -920,7 +916,7 @@ class KhweeteurWin(QMainWindow):
             screenname = self.model.data(index, role=SCREENNAMEROLE)
 
         if not (( QMessageBox.question(None,
-            "Kheeteur Follow",
+            "Khweeteur Follow",
             "Did you really want to follow '%s'?" % screenname,
             QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
             user_id = None
@@ -954,7 +950,7 @@ class KhweeteurWin(QMainWindow):
             screenname = self.model.data(index, role=SCREENNAMEROLE)
 
         if not (( QMessageBox.question(None,
-            "Kheeteur Unfollow",
+            "Khweeteur Unfollow",
             "Did you really want to unfollow '%s'?" % screenname,
             QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
             user_id = None
@@ -987,6 +983,7 @@ class KhweeteurWin(QMainWindow):
         self.tb_list_button.setChecked(False)
         self.tb_search_button.setChecked(False)
         self.home_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.view.scrollToTop()
         self.model.load('Mentions')
         self.setWindowTitle('Khweeteur : Mentions')
@@ -1000,11 +997,37 @@ class KhweeteurWin(QMainWindow):
         self.home_button.setChecked(False)
         self.tb_search_button.setChecked(False)
         self.mention_button.setChecked(False)
+        self.near_button.setChecked(False)
         self.view.scrollToTop()
         self.model.load('DMs')
         self.setWindowTitle('Khweeteur : DMs')
         self.delete_search_action.setVisible(False)
 
+    @Slot()
+    def show_nears(self):
+        settings = QSettings()
+        if settings.value('useGPS') != '2':
+            if (( QMessageBox.question(None,
+                "Khweeteur",
+                'This feature require the activation of the GPS, would you want to activate it now ?',
+                QMessageBox.Yes| QMessageBox.Close)) ==  QMessageBox.Yes):
+                    settings.setValue('useGPS','2')
+                    settings.sync()
+                    self.geolocDoStart()
+                    self.dbus_handler.require_update()
+
+        self.near_button.setCounter(0)
+        self.near_button.setChecked(True)
+        self.msg_button.setChecked(False)
+        self.tb_list_button.setChecked(False)
+        self.home_button.setChecked(False)
+        self.tb_search_button.setChecked(False)
+        self.mention_button.setChecked(False)
+        self.view.scrollToTop()
+        self.model.load('Nears')
+        self.setWindowTitle('Khweeteur : Near Tweets')
+        self.delete_search_action.setVisible(False)
+
     @Slot()
     def countCharsAndResize(self):
         local_self = self.tb_text
@@ -1012,34 +1035,7 @@ class KhweeteurWin(QMainWindow):
                                     - len(local_self.toPlainText())))
         doc = local_self.document()
         fm = local_self.fontMetrics()
-#        line_height = fm.boundingRect(local_self.toPlainText()).height()
 
-#        height = (line_height ) * doc.documentLayout().documentSize().height() + fm.lineSpacing()
-#        s = doc.documentLayout().documentSize()
-
-#        print 'Doc size', doc.size().height()
-
-#        doc.setHeight(s.height())
-#        s.setHeight((s.height() + 2) + (local_self.fontMetrics().lineSpacing()*2 + 2))
-#        s.setHeight(s.height())
-#        print 'Doc size', s.height()
-#        fr = local_self.frameRect()
-#        print 'frame size', fr.size().height()
-#        cr = local_self.contentsRect()
-#        print 'content size', cr.size().height()
-#        print 'page size', doc.pageSize().height()
-#        print 'page count', doc.pageCount()
-#        local_self.setFixedHeight(min(370, s.height() + fr.height()
-#                                  - cr.height() - 1))
-#        text_height = fm.boundingRect(0,0,local_self.size().width(),370, \
-#                    int(Qt.AlignTop) | int(Qt.AlignLeft) | int(Qt.TextWordWrap), \
-#                    local_self.toPlainText()).height()
-#        print 'text height',text_height
-#        if height > 5 :
-#        local_self.setFixedHeight(min(370, text_height + (fr.height() - cr.height()) + 6))
-#        local_self.updateGeometry()
-#Resize
-#        doc = self.document()
         s = doc.size().toSize()
         s.setHeight((s.height() + 1) * (fm.lineSpacing()+1))
         fr = local_self.frameRect()
